#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Drawing;
using System.Windows.Forms;

namespace HeuristicLab.Visualization {
  public interface IChart {
    bool Enabled { get; set; }
    Color BackgroundColor { get; set; }

    PointD LowerLeft { get; }
    PointD UpperRight { get; }
    SizeD Size { get; }
    Size SizeInPixels { get; }
    SizeD PixelToWorldRatio { get; }
    SizeD WorldToPixelRatio { get; }
    IGroup Group { get; }

    PointD TransformPixelToWorld(Point point);
    SizeD TransformPixelToWorld(Size size);
    Point TransformWorldToPixel(PointD point);
    Size TransformWorldToPixel(SizeD size);

    void SetPosition(PointD lowerLeft, PointD upperRight);
    void Move(Offset delta);

    void ZoomIn(Point mousePosition);
    void ZoomIn(PointD lowerLeft, PointD upperRight);
    void ZoomIn(Point lowerLeft, Point upperRight);
    void ZoomOut();
    void Unzoom();

    void IntoForeground(IPrimitive primitive);
    void IntoBackground(IPrimitive primitive);
    void OneLayerUp(IPrimitive primitive);
    void OneLayerDown(IPrimitive primitive);

    string GetToolTipText(Point point);
    Cursor GetCursor(Point point);

    IPrimitive GetPrimitive(Point point);
    IEnumerable<IPrimitive> GetAllPrimitives(Point point);

    void Render(Graphics graphics, int width, int height);

    event EventHandler RedrawRequired;
    void RaiseRedrawRequired();
  }
}
